<?php

/**
 * Component to the insert and update a model several times on a form, ideal when you have a relationship HAS-MANY
 * relationship between models.
 * Usage:
 * # Add in the actions of the controller, the action (ext.ajaxInput.AddItemAction) that adds a new view of mode
 *  public function actions() {
 *      'addItem' => 'ext.ajaxInput.AddItemAction',
 *  }
 * # Call the widget in your create/update view, inside your form:
 *  echo CHtml::link('Add new model', null, array(
 *      'class' => 'btn btn-info addItem',
 *      'model' => 'TestModel',
 *      'view' => '_testForm'
 *  ));
 * @version 1.0
 * @author Rafael J Torres <rafaelt88@gmail.com>
 * @copyright (c) 2014 Rafael J Torres
 * @license GNU/GPL: http://www.gnu.org/copyleft/gpl.html
 */
class AddItemAction extends CAction {

    public function run($modelClass, $view) {
        if (! Yii::app()->request->isAjaxRequest) return;
        $model = new $modelClass();
        $index = Yii::app()->user->getState($modelClass, 0);
        $this->controller->renderPartial($view, 
            array(
                'model' => $model,
                'index' => $index ++
            ), false, true);
        Yii::app()->user->setState($modelClass, $index);
    }

}