<?php

/**
 * Component to the insert and update a model several times on a form, ideal when you have a relationship HAS-MANY
 * relationship between models.
 * Usage:
 * # Call the widget in your create/update view, inside your form
 *  $this->widget('ext.ajaxInput.AjaxInputWidget', array(
 *      'modelClass' => 'TestModel',
 *      'view' => '_testForm',
 *      'ajaxUrl' => $this->createUrl('addItem'),
 *      //'items' => $items // Only for update, this contain a array of the models
 *  ));
 * @version 1.0
 * @author Rafael J Torres <rafaelt88@gmail.com>
 * @copyright (c) 2014 Rafael J Torres
 * @license GNU/GPL: http://www.gnu.org/copyleft/gpl.html
 */
class AjaxInputWidget extends CWidget {
    public $modelClass;
    public $view;
    public $ajaxUrl;
    public $items;
    public $append = true;

    public function init() {
        Yii::app()->clientScript->registerScript('AjaxInputWidget', 
            'function removeItem(model, index) {
                $("[" + model + "="  + index + "]").remove();
            }
            $(".addItem").on("click", function(e){
            	var model = $(this).attr("model");
                var view = $(this).attr("view");
                $.ajax({
                    url: "' . $this->ajaxUrl . '",
                    data : {"modelClass" : model, "view" : view},
                    success: function(data){
            	        $("div[list=" + model + "]").' . ($this->append ? 'append' : 'prepend') . '(data);
                    }
                });
            });', CClientScript::POS_END);
    }

    public function run() {
        echo '<div list="' . $this->modelClass . '" class="col-xs-12">';
        $data = array();
        if (is_array($this->items)) {
            $index = 0;
            foreach ($this->items as $item) {
                if (isset($item['index'])) $item->index = $index ++;
                $data[] = $item->getAttributes();
            }
            Yii::app()->user->setState($this->modelClass, count($data));
        }
        foreach (Yii::app()->request->getParam($this->modelClass, $data) as $index => $values) {
            $model = new $this->modelClass();
            $model->setAttributes($values);
            if (isset($values['id'])) {
                $model->id = $values['id'];
            }
            $model->validate();
            Yii::app()->controller->renderPartial($this->view, 
                array(
                    'model' => $model,
                    'index' => $index
                ));
        }
        echo '</div>';
    }

}
